import 'package:flutter_test/flutter_test.dart';

import 'package:numerology/numerology.dart';

void main() {
  final _instance = NumerologyCalculator();
  final day08011998 = DateTime(1998, 1, 8); // Ruling: 9
  final day22121999 = DateTime(1999, 12, 22); //  Ruling: 8
  final day03071551 = DateTime(1551, 7, 3); // Ruling: 22
  final sumNumString = "1123"; // 7
  final sumNumString2 = "56789"; // 35
  final universalYear5 = DateTime(2021); // 5

  test("Test sum num from text", () {
    expect(_instance.sumNumText(sumNumString), 7);
    expect(_instance.sumNumText(sumNumString2), 35);
    expect(_instance.sumNumText(""), null);
  });

  test("Test dd-MM-yyyt fomat", () {
    expect(_instance.toDdMnYyyy(day08011998), "08-01-1998");
    expect(_instance.toDdMnYyyy(day22121999), "22-12-1999");
  });

  test("Test ddMMyyyy fomat", () {
    expect(_instance.toDmy(day08011998), "08011998");
    expect(_instance.toDmy(day22121999), "22121999");
  });

  test("Test Ruling number", () {
    expect(_instance.rulingNumber(day08011998), 9);
    expect(_instance.rulingNumber(day22121999), 8);
    expect(_instance.rulingNumber(day03071551), 22);
  });

  test("Test Universal Year Number", () {
    expect(_instance.universalYearNumber(dateTime: day22121999), 1);
    expect(_instance.universalYearNumber(dateTime: day08011998), 9);
    expect(_instance.universalYearNumber(dateTime: day03071551), 3);
  });

  test("Test Personal Year", () {
    expect(_instance.personalYear(day08011998, currentYear: universalYear5), 5);
    expect(_instance.personalYear(day22121999, currentYear: universalYear5), 3);
    expect(_instance.personalYear(day03071551, currentYear: universalYear5), 6);
  });

  test("Test Personal Month", () {
    expect(
        _instance.personalMonth(
          day08011998.add(Duration(days: 90)), // 08-04-1998
          day08011998,
        ),
        4); // ((1998) + 8 + 1) + 4 = (9 + 8 + 1) + 4 = 9 + 4 = 4
    expect(
        _instance.personalMonth(
          day22121999.add(Duration(days: 10)), // 1-1-2000
          day22121999,
        ),
        1); // ((2000) + 12 + 22) + 1 = (2 + 12 + 22) + 1 = 9 + 1 = 1
    expect(
        _instance.personalMonth(
          day08011998, // 08-01-1998
          day03071551,
        ),
        2); // ((1998) + 7 + 3) + 1 = (9 + 7 + 3) + 1 = 1 + 1 = 2
  });

  test("Test Personal Day", () {
    expect(
        _instance.personalDay(
          day08011998.add(Duration(days: 90)), // 08-04-1998
          day08011998,
        ),
        3); // Personal month: 4, day = 8 -> Personal day = 4 + 8 = 12 -> 1 + 2 = 3
    expect(
        _instance.personalDay(
          day22121999.add(Duration(days: 10)), // 1-1-2000
          day22121999,
        ),
        2); // Personal month: 1, day = 1 -> Personal day = 1 + 1 = 2
    expect(
        _instance.personalDay(
          day08011998, // 08-01-1998
          day03071551,
        ),
        1); // Personal month: 2, day = 8 -> Personal day = 2 + 8 = 10 -> 1 + 0 = 1
  });

  test("Test lifePathNumber", () {
    expect(_instance.lifePathNumber(day08011998),
        9); // 8 + 1 + (1998) = 8 + 1 + 9 = 18 -> 1 + 8 = 9
    expect(_instance.lifePathNumber(day22121999),
        8); // 22 + 3 + (1999) = 22 + 3 + 1 = 26 -> 2 + 6 = 8
    expect(_instance.lifePathNumber(day03071551),
        4); // 3 + 7 + (1551) = 3 + 7 + 3 = 13 -> 1 + 3 = 4
  });

  test("Test Attitude Number", () {
    expect(
      _instance.attitudeNumber(day03071551),
      1,
    ); // 3 + 7 = 10 -> 1 + 0 = 1
    expect(
      _instance.attitudeNumber(day22121999),
      7,
    ); // 22 + 12 = 34 -> 3 + 4 = 7
    expect(_instance.attitudeNumber(day08011998), 9); // 8 + 1 = 9
  });

  test("Tets sumReduceNumText", () {
    expect(_instance.sumReduceNumText('12345'), 6);
    expect(_instance.sumReduceNumText('99999'), 9);
    expect(_instance.sumReduceNumText('78901'), 7);
  });
}
